// rBigNumbers - Display big numbers on an I2C LCD display 16x2 (one row) or 20x4 (two rows)
// Library based upon this project: https://github.com/seanauff/BigNumbers
// Requires library rLiquidCrystal_I2C v1.03
// Each character displayed uses 2 row height and 3 olumns width.
// @author Robert W.B. Linn @ www.rwblinn.de
// @since 20170130 
#pragma once
#include "B4RDefines.h"
#include "BigNumbers.h"
namespace B4R {
	//~version: 1.0
	//~shortname: BigNumbers_I2C
	class B4RBigNumbers_I2C {
		private:
			BigNumbers* bn;
			uint8_t be[sizeof(BigNumbers)];
		public:
			// Init the bignumbers with LCD display (has to be initialized first)
			void Initialize(B4RLiquidCrystal_I2C* lcd);

			// Clear the number
			// col - column of upper left corner for large charcter
			// row - row to clear (0 on 16x2, 0 or 1 on 16x4 or 20x4)
    	void ClearLargeNumber(Byte col, Byte row);

			// Display a number (0 - 9)
			// n - number to display
			// col - column of upper left corner for large character
			// row - row to display (0 on 16x2, 0 or 1 on 16x4 or 20x4)
    	void DisplayLargeNumber(Byte n, Byte col, Byte row);

			// Display an integer (0 - 32767)
			// n - integer to display
			// col - column of upper left corner of first large character
			// row - row to display (0 on 16x2, 0 or 1 on 16x4 or 20x4)
			// digits - number of digits of the integer (specifiying this allows the digit positions to remain constant when printing out ints of various lengths)
			// leading - sets if leading zeros are printed or not (false = no, true = yes)
			void DisplayLargeInt(Int n, Byte col, Byte row, Byte digets, bool leading);
	};
}